@@ -1,9 +1,11 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-import os
+import os, sys
 import time
 import json
 import click
+from pathlib import Path
+from click_help_colors import HelpColorsGroup
 
 
 # Local module imports
@@ -11,6 +13,7 @@ from bbbmon.xmldict import XmlListConfig, XmlDictConfig
 from bbbmon.configuration import Config, Endpoint, SERVER_PROPERTIES_FILE, Url, Secret, get_user_config_path, init_config, new_config
 from bbbmon.meetings import *
 from bbbmon.printing import *
+from bbbmon.load import *
 
 
 
@@ -18,8 +21,7 @@ from bbbmon.printing import *
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 
 
-
-class AliasedGroup(click.Group):
+class AliasedGroup(HelpColorsGroup):
     """
     Subclass of Group to allow abbreviating commands like this:
     Instead of `bbbmon meetings` one could type `bbbmon m`
@@ -37,10 +39,13 @@ class AliasedGroup(click.Group):
         ctx.fail('Too many matches: %s' % ', '.join(sorted(matches)))
 
 
-@click.group(context_settings=CONTEXT_SETTINGS, cls=AliasedGroup)
+@click.group(context_settings=CONTEXT_SETTINGS, cls=AliasedGroup, invoke_without_command=True,
+    help_headers_color='yellow',
+    help_options_color='green')
 @click.option('--userconfig', '-u', is_flag=True, help="Use user config even if on server")
 @click.option('--watch', '-w', help="Run repeatedly with the given interval in seconds", type=click.IntRange(2, 2147483647, clamp=True))
-def main(userconfig, watch):
+@click.option('--version', '-V', is_flag=True, help="Show version")
+def main(userconfig, watch, version):
     """BBBMON is a small CLI utility to monitor bbb usage
 
     \b
@@ -49,7 +54,12 @@ def main(userconfig, watch):
 
     Internally bbbmon relies on the offical bbb-API, which means you need to have the server's secret in order to create a valid request. Create a new configuration with: bbbmon config --new
     """
-    pass 
+    __version__ = "0.1.32"
+
+    if version:
+        print(__version__)
+    else:
+        pass 
 
 
 
@@ -59,6 +69,7 @@ def main(userconfig, watch):
 @click.option('--endpoint', '-e', multiple=True, help="Filter by one or more endpoints as named in the user configuration (e.g. [servername]). Order is respected.")
 @click.option('--watch', '-w', help="Run repeatedly with the given interval in seconds", type=click.IntRange(2, 2147483647, clamp=True))
 @click.option('-n', help="The number of meetings to show in the leaderboards (Default: 5)", type=int)
+@click.option('--read-load-from', help="Read the load from file/https (if starts with http(s) request, else read from path). Looks for floats and calculates the average.", type=str)
 @click.option('--leaderboards/--no-leaderboards', default=True, show_default=True, help="Hide or show the meeting leaderboards")
 @click.option('--participants/--no-participants', default=True, show_default=True, help="Hide or show the participants")
 @click.option('--meetings/--no-meetings', default=True, show_default=True, help="Hide or show the meetings")
@@ -69,7 +80,8 @@ def main(userconfig, watch):
 @click.option('--twolines', '-2', is_flag=True, help="Print essentials on two lines")
 @click.option('--all', '-a', 'all_', is_flag=True, help="Print all")
 @click.option('--fancy/--no-fancy', default=False, show_default=True, help="Use fancy headers")
-def meetings(ctx, userconfig, watch, short, compact, n, all_, twolines, leaderboards, participants, presenter, presenter_id, meetings, endpoint, fancy):
+@click.option('--sum','sum_', is_flag=True, help="Print all")
+def meetings(ctx, userconfig, watch, short, compact, n, all_, twolines, read_load_from, leaderboards, participants, presenter, presenter_id, meetings, endpoint, fancy, sum_):
     """View currently active meetings"""
     if short:
         leaderboards = False
@@ -89,18 +101,25 @@ def meetings(ctx, userconfig, watch, short, compact, n, all_, twolines, leaderbo
 
     config = init_config(userconfig)
     config.filter_endpoints(endpoint)
+
+    # Load is none if it doesn't work
+    load = read_load(read_load_from)
+
     if watch is not None:
         while watch is not None:
-            if twolines:
-                meetings_twolines(config, watch, fancy)
-            else:
-                list_meetings(config, leaderboards, n, participants, presenter, presenter_id, meetings, watch, fancy, compact)
-            time.sleep(watch)
+            try:
+                if twolines:
+                    meetings_twolines(config, watch, fancy, sum_, load)
+                else:
+                    list_meetings(config, leaderboards, n, participants, presenter, presenter_id, meetings, watch, fancy, compact, sum_, load)
+                time.sleep(watch)
+            except KeyboardInterrupt:
+                sys.exit()
     else:
         if twolines:
-            meetings_twolines(config, watch, fancy)
+            meetings_twolines(config, watch, fancy, sum_, load)
         else:
-            list_meetings(config, leaderboards, n, participants, presenter, presenter_id, meetings, watch, fancy, compact)
+            list_meetings(config, leaderboards, n, participants, presenter, presenter_id, meetings, watch, fancy, compact, sum_, load)
 
 
 
@@ -155,12 +174,40 @@ def json(ctx, userconfig, watch, endpoint, compact):
         exit()
     if watch is not None:
         while watch is not None:
-            print(format_json(config, watch, compact))
-            time.sleep(watch)
+            try:
+                print(format_json(config, watch, compact))
+                time.sleep(watch)
+            except KeyboardInterrupt:
+                sys.exit()
     else:
         print(format_json(config, watch, compact))
 
 
+@main.command(context_settings=CONTEXT_SETTINGS)
+@click.pass_context
+@click.option('--watch', '-w', help="Run repeatedly with the given interval in seconds", type=click.IntRange(2, 2147483647, clamp=True))
+@click.option('--compact/--pretty', '-c/-p', default=False, show_default=True, help="Print pretty and indented json or compact")
+@click.option('--userconfig', '-u', is_flag=True, help="Use user config even if on server")
+@click.option('--endpoint', '-e', multiple=True, help="Filter by one or more endpoints as named in the user configuration (e.g. [servername]). Order is respected.")
+def raw(ctx, userconfig, watch, endpoint, compact):
+    """Print raw response"""
+    config = init_config(userconfig)
+    config.filter_endpoints(endpoint)
+    if not config.endpoints:
+        exit()
+    if watch is not None:
+        while watch is not None:
+            try:
+                for m in format_raw(config, watch, compact):
+                    print(m)
+                time.sleep(watch)
+            except KeyboardInterrupt:
+                sys.exit()
+    else:
+        for m in format_raw(config, watch, compact):
+            print(m)
+
+
 
 
 if __name__ == "__main__":
