@@ -88,7 +88,7 @@ class Config():
             filtered_endpoints = []
             for endpoint_option in endpoint_options:
                 if not endpoint_option in existing_names:
-                    click.echo("{} there is no endpoint called \"{}\" in the configuration. It will be ignored.\n".format(click.style('Error:', fg='red', bold=True), click.style(endpoint_option, fg='red', bold=True)))
+                    click.echo("{} there is no endpoint called \"{}\" in the configuration. It will be ignored.\n".format(click.style('Error:', fg='red', bold=True), click.style(endpoint_option, fg='red', bold=True)), err=True)
                     if self.on_server:
                         click.echo("{} bbbmon is using the server config. You can use a user config using the {} flag.\n".format(click.style('Hint:', fg='yellow', bold=True), click.style("--userconfig", fg='bright_black', bold=True)))
                     if len(self.endpoints) > 0:
@@ -164,14 +164,14 @@ def new_config(user_config_path: str, skip_prompt: bool=True):
     if asking and printing should be done elsewhere)
     """
     if not skip_prompt:
-        click.echo("{} There was no config file found. Make sure it exists and is readable at either location:".format(click.style('Error:', fg='red', bold=True), click.style("Error:", fg='red', bold=True)))
-        print("       [0] {}".format(SERVER_PROPERTIES_FILE))
-        print("       [1] {}".format(user_config_path))
-        print()
-        print("For now the file just needs to contain three lines:")
+        click.echo("{} There was no config file found. Make sure it exists and is readable at either location:".format(click.style('Error:', fg='red', bold=True), click.style("Error:", fg='red', bold=True)), err=True)
+        eprint("       [0] {}".format(SERVER_PROPERTIES_FILE))
+        eprint("       [1] {}".format(user_config_path))
+        eprint()
+        eprint("For now the file just needs to contain three lines:")
         for line in EXAMPLE_CONFIG.splitlines():
-            click.echo(click.style((line), fg="bright_black"))
-        print()
+            click.echo(click.style((line), fg="bright_black"), err=True)
+        eprint()
 
     if skip_prompt or click.confirm(click.style('Do you want to create a config file at {}?'.format(user_config_path), fg="green"), abort=True):
         # Create all directories in the path to the config, if they don't exist yet
